@@ -1,11 +1,11 @@
 from gym_recsys.envs import SlateSpace
 from gym_recsys.envs import Env
+from gym_recsys.envs import CTRReward, SkipPenaltyReward, PreferenceRewardDeterministic, PreferenceRewardStochastic
 
 from gym.envs.registration import register
 
 
-ts = [10, 50, 100, 200, 500, 1000]
-for t in ts:
+for t in range(1, 1000+1):
     register(
         id=f'RecSys-t{t}-v0',
         entry_point='gym_recsys.envs:Env',
